"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Joi = __importStar(require("joi"));
const field_list_1 = __importDefault(require("./field-list"));
const index_1 = require("./types/index");
/**
 * Class which validates database fields using white list and black list.
 */
class AllowedFields {
    /**
     * Creates object.
     * @param     {Object}  [config]            - Configuration
     * @param     {Fields}  [config.whiteList]  - List of allowed identifiers (entities and fields) to be used in query.
     * @param     {Fields}  [config.blackList]  - List of identifiers which are prohibited to use in query.
     * @return    {AllowedFields}               - Allowed fields
     * @example
     * const employees = new AllowedFields(
     *   whiteList: { '': 'color', member: '*', manager: ['name', 'surname'] },
     *   blackList: { member: ['salary', 'id'] },
     * );
     * employees.isAllowed('member.name');    // true
     * employees.isAllowed('color');          // true
     * employees.isAllowed('manager.name');   // true
     * employees.isAllowed('member.salary');  // false
     * employees.isAllowed('manager.salary'); // false
     */
    constructor(config) {
        const validation = Joi.validate(config, index_1.AllowedFieldsConfigSchema);
        const { whiteList, blackList } = config;
        if (validation.error) {
            throw new Error(validation.error.annotate());
        }
        this._whiteList = whiteList ? new field_list_1.default(whiteList) : undefined;
        this._blackList = blackList ? new field_list_1.default(blackList) : undefined;
    }
    /**
     * Returns whether given field/relation combination is an allowed field according to given rules.
     * Field name can be provided in single parameter or two parameters: i.e ('name', 'member')  or ('member.name').
     * @param     {string}          fieldName           - Field name to test. i.e `'name'`. Also it may contain field name such as 'member.name'
     * @param     {string}          [relationName='']   - Relation name which field belongs to.
     * @returns   {boolean}                             - Whether field is valid.
     * @example
     * allowedFields.isAllowed('member.name');    // Table and field as a single string.
     * allowedFields.isAllowed('name', 'member'); // Field, Table.
     */
    isAllowed(fieldName, relationName = "") {
        const [relation, field] = fieldName.match(/\./) ? fieldName.split(".") : [relationName, fieldName];
        // * return false. Also relation.* returns false if any field of the relation is in blacklist.
        const starError = field === "*" && (!relation || (this._blackList && this._blackList.hasRelation(relation)));
        const whiteListError = this._whiteList && !this._whiteList.has(field, relation);
        const blackListError = this._blackList && this._blackList.has(field, relation);
        return !(starError || whiteListError || blackListError);
    }
}
exports.default = AllowedFields;
//# sourceMappingURL=index.js.map